#!/bin/bash

# by Eriberto
# Create the manpage using txt2man command.

###########
# linssid #
###########
T2M_DATE="11 Oct 2018"
T2M_NAME=linssid
T2M_VERSION=3.6
T2M_LEVEL=8
T2M_DESC="graphical wireless scanner"

# Don't change the following line
txt2man -d "$T2M_DATE" -t $T2M_NAME -r $T2M_NAME-$T2M_VERSION -s $T2M_LEVEL -v "$T2M_DESC" $T2M_NAME.txt > $T2M_NAME.$T2M_LEVEL

##################
# linssid-pkexec #
##################
T2M_DATE="11 Oct 2018"
T2M_NAME=linssid-pkexec
T2M_VERSION=3.6
T2M_LEVEL=1
T2M_DESC="graphical wireless scanner"

# Don't change the following line
txt2man -d "$T2M_DATE" -t $T2M_NAME -r $T2M_NAME-$T2M_VERSION -s $T2M_LEVEL -v "$T2M_DESC" $T2M_NAME.txt > $T2M_NAME.$T2M_LEVEL
